package com.chargeitpro.chargeitpro_demopos;

import android.app.Activity;
import android.app.AlertDialog;
import android.content.Context;
import android.content.SharedPreferences;
import android.os.Handler;
import android.os.Looper;

import com.google.gson.Gson;

import java.io.BufferedReader;
import java.io.DataOutputStream;
import java.io.InputStreamReader;
import java.net.HttpURLConnection;
import java.net.URL;

import model.MobileActivateResponse;
import model.MobileTransactionRequest;
import model.MobileTransactionResponse;
import model.MobileTransactionResult;

public class ChargeItProAPI
{
    public static String mobileTransactionId;

    private static final String  apiKey = "<INSERT-YOUR-API-KEY-HERE>"; // <-- For real, insert your API key right there...

    private static final String  urlMobileTransaction = "https://api.chargeitpro.com/Mobile/Transaction/";
    private static final String  urlMobileTransactionResult = "https://api.chargeitpro.com/Mobile/TransactionResult/";
    private static final String urlMobileActivate = "https://api.chargeitpro.com/Mobile/Activate/";

    public static MobileActivateResponse activateDeviceUsingActivationKey(String activationKey) throws Exception
    {
        // Create the URL object
        URL url = new URL(ChargeItProAPI.urlMobileActivate + activationKey);

        // Create the connection object
        HttpURLConnection connection = (HttpURLConnection)url.openConnection();
        connection.setRequestMethod("GET");
        connection.setRequestProperty("apikey", ChargeItProAPI.apiKey);
        connection.setUseCaches(false);

        // Read the response
        BufferedReader reader = new BufferedReader(new InputStreamReader(connection.getInputStream()));
        StringBuilder stringBuilder = new StringBuilder();
        String line = null;
        while ((line = reader.readLine()) != null)
        {
            stringBuilder.append(line + "\n");
        }
        String response = stringBuilder.toString();

        // Turn the JSON string into a MobileActivateResponse object
        // NOTE: This is not all of the fields available in the response
        Gson gson = new Gson();
        MobileActivateResponse mobileActivateResponse = gson.fromJson(response, MobileActivateResponse.class);

        // Return the MobileActivateResponse
        return mobileActivateResponse;
}

    public static MobileTransactionResponse createNewMobileTransaction(final Activity activity, String transactionType, String amount, String cashierName, String referenceNumber) throws Exception
    {
        // Clear the current state data
        ChargeItProAPI.clear();

        // Get the ConfigurationID
        SharedPreferences preferences = activity.getApplicationContext().getSharedPreferences("Configuration", Context.MODE_PRIVATE);
        String configurationId = preferences.getString("ConfigurationId", null);

        // Make sure the ConfigurationID exists
        if (configurationId != null) {
            // Create a MobileTransactionRequest object (will be turned into JSON via GSON)
            MobileTransactionRequest mobileTransactionRequest = new MobileTransactionRequest();

            // Add the configuration ID; necessary to interact with the TSL
            mobileTransactionRequest.ConfigurationId = configurationId;

            // Set the cashier name
            mobileTransactionRequest.Cashier = cashierName;

            // Set the transaction type
            mobileTransactionRequest.TransactionType = transactionType;

            // Set the reference number (might be null)
            mobileTransactionRequest.RefNum = referenceNumber;

            // Set the amount (might be null)
            mobileTransactionRequest.Amount = amount;

            // Convert this object into a JSON string
            Gson gson = new Gson();
            String mobileTransactionRequestJsonString = gson.toJson(mobileTransactionRequest);

            // Create a byte[] from the JSON string
            byte[] mobileTransactionRequestJsonStringByteArray = mobileTransactionRequestJsonString.getBytes();

            // Create the URL object
            URL url = new URL(ChargeItProAPI.urlMobileTransaction);

            // Create the connection object
            HttpURLConnection connection = (HttpURLConnection) url.openConnection();
            connection.setRequestMethod("POST");
            connection.setRequestProperty("Content-Type", "application/json");
            connection.setRequestProperty("Content-Length", Integer.toString(mobileTransactionRequestJsonStringByteArray.length));
            connection.setRequestProperty("apikey", ChargeItProAPI.apiKey);
            connection.setUseCaches(false);

            // Write the POST data
            DataOutputStream dataOutputStream = new DataOutputStream(connection.getOutputStream());
            dataOutputStream.write(mobileTransactionRequestJsonStringByteArray);

            // Read the response
            BufferedReader reader = new BufferedReader(new InputStreamReader(connection.getInputStream()));
            StringBuilder stringBuilder = new StringBuilder();
            String line = null;
            while ((line = reader.readLine()) != null) {
                stringBuilder.append(line + "\n");
            }
            String response = stringBuilder.toString();

            // Create the MobileTransactionResponse object
            MobileTransactionResponse mobileTransactionResponse = gson.fromJson(response, MobileTransactionResponse.class);

            // Save the mobileTransactionId
            ChargeItProAPI.mobileTransactionId = mobileTransactionResponse.Result.MobileTransactionId;

            // Return this MobileTransactionResponse
            return mobileTransactionResponse;
        }
        else
        {
            // Get a handler that can be used to post to the main thread
            Handler mainHandler = new Handler(Looper.getMainLooper());
            Runnable myRunnable = new Runnable() {
                @Override
                public void run() {
                    AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(activity);
                    alertDialogBuilder.setTitle("Error");
                    alertDialogBuilder.setMessage("Please enter a valid Activation Key. If you do not have an Activation Key, please contact ChargeItPro for help: 1-800-989-2135");
                    alertDialogBuilder.setPositiveButton("OK", null);
                    AlertDialog alertDialog = alertDialogBuilder.create();
                    alertDialog.show();
                }
            };
            mainHandler.post(myRunnable);

            return null;
        }
    }

    public static MobileTransactionResult getMobileTransactionResult(String mobileTransactionId) throws Exception
    {
        // Create the URL object
        URL url = new URL(ChargeItProAPI.urlMobileTransactionResult + mobileTransactionId);

        // Create the connection object
        HttpURLConnection connection = (HttpURLConnection)url.openConnection();
        connection.setRequestMethod("GET");
        connection.setRequestProperty("apikey", ChargeItProAPI.apiKey);
        connection.setUseCaches(false);

        // Read the response
        BufferedReader reader = new BufferedReader(new InputStreamReader(connection.getInputStream()));
        StringBuilder stringBuilder = new StringBuilder();
        String line = null;
        while ((line = reader.readLine()) != null)
        {
            stringBuilder.append(line + "\n");
        }
        String response = stringBuilder.toString();

        // Turn the JSON string into a MobileTransactionResult object
        // NOTE: This is not all of the fields available in the response
        Gson gson = new Gson();
        MobileTransactionResult mobileTransactionResult = gson.fromJson(response, MobileTransactionResult.class);

        // Return the MobileTransactionResult
        return mobileTransactionResult;
    }

    public static void clear()
    {
        ChargeItProAPI.mobileTransactionId = null;
    }
}
