package com.chargeitpro.chargeitpro_demopos;

import android.app.AlertDialog;
import android.content.Intent;
import android.os.AsyncTask;
import android.os.Handler;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.view.View;
import android.widget.AdapterView;
import android.widget.ArrayAdapter;
import android.widget.ListView;

import model.MobileTransactionResult;

public class MainActivity extends AppCompatActivity {

    ListView listView;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // Check to see if the mobile transaction id exists
        if (ChargeItProAPI.mobileTransactionId != null)
        {
            AsyncTask.execute(new Runnable() {

                @Override
                public void run() {
                    try {
                        // Get the MobileTransactionResult object
                        final MobileTransactionResult mobileTransactionResult = ChargeItProAPI.getMobileTransactionResult(ChargeItProAPI.mobileTransactionId);

                        // If the Result object exists
                        if (mobileTransactionResult.Result != null && mobileTransactionResult.Result.ResultStatus.equals("true")) {
                            // Get a handler that can be used to post to the main thread
                            Handler mainHandler = new Handler(MainActivity.this.getMainLooper());
                            Runnable myRunnable = new Runnable() {
                                @Override
                                public void run() {
                                    AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(MainActivity.this);
                                    alertDialogBuilder.setTitle("Success");
                                    alertDialogBuilder.setMessage("Transaction was successful" +
                                            (mobileTransactionResult.Result.UniqueTransId != "" ?
                                                    "- UniqueTransId (a.k.a. RefNum) is: " + mobileTransactionResult.Result.UniqueTransId :
                                                    ""));
                                    alertDialogBuilder.setPositiveButton("OK", null);
                                    AlertDialog alertDialog = alertDialogBuilder.create();
                                    alertDialog.show();
                                }
                            };
                            mainHandler.post(myRunnable);

                        } else if (mobileTransactionResult.Error != null) { // Else, an error occurred during this call
                            // Get a handler that can be used to post to the main thread
                            Handler mainHandler = new Handler(MainActivity.this.getMainLooper());
                            Runnable myRunnable = new Runnable() {
                                @Override
                                public void run() {
                                    AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(MainActivity.this);
                                    alertDialogBuilder.setTitle("Failure");
                                    alertDialogBuilder.setMessage(mobileTransactionResult.Error.Message);
                                    alertDialogBuilder.setPositiveButton("OK", null);
                                    AlertDialog alertDialog = alertDialogBuilder.create();
                                    alertDialog.show();
                                }
                            };
                        } else { // Else, something else happened
                            // Get a handler that can be used to post to the main thread
                            Handler mainHandler = new Handler(MainActivity.this.getMainLooper());
                            Runnable myRunnable = new Runnable() {
                                @Override
                                public void run() {
                                    AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(MainActivity.this);
                                    alertDialogBuilder.setTitle("Failure");
                                    alertDialogBuilder.setMessage("An unknown error occurred.");
                                    alertDialogBuilder.setPositiveButton("OK", null);
                                    AlertDialog alertDialog = alertDialogBuilder.create();
                                    alertDialog.show();
                                }
                            };
                            mainHandler.post(myRunnable);
                        }
                    } catch (final Exception e) {
                        // Get a handler that can be used to post to the main thread
                        Handler mainHandler = new Handler(MainActivity.this.getMainLooper());
                        Runnable myRunnable = new Runnable() {
                            @Override
                            public void run() {
                                AlertDialog.Builder alertDialogBuilder = new AlertDialog.Builder(MainActivity.this);
                                alertDialogBuilder.setTitle("Exception");
                                alertDialogBuilder.setMessage(e.getMessage());
                                alertDialogBuilder.setPositiveButton("OK", null);
                                AlertDialog alertDialog = alertDialogBuilder.create();
                                alertDialog.show();
                            }
                        };
                        mainHandler.post(myRunnable);
                    }
                }
            });
        }

        // Get the ListView
        listView = (ListView) findViewById(R.id.listView);

        // Create the array of data that will be displayed on the ListView
        String[] listViewData = new String[] {"Activate", "CreditSale", "CreditReturn", "GenericVoid", "RequestSignature"};

        // Create a new array for this ListView
        ArrayAdapter<String> adapter = new ArrayAdapter<String>(this, android.R.layout.simple_list_item_1, android.R.id.text1, listViewData);

        // Set the ListView's adapter
        listView.setAdapter(adapter);

        // ListView Item Click Listener
        listView.setOnItemClickListener(new AdapterView.OnItemClickListener() {

            @Override
            public void onItemClick(AdapterView<?> parent, View view,
                                    int position, long id) {

                // ListView Clicked item index
                int itemPosition = position;

                // ListView Clicked item value
                String itemValue = (String) listView.getItemAtPosition(position);

                // If user clicked on "Activate"
                if (itemPosition == 0)
                {
                    Intent intent = new Intent(MainActivity.this, ActivateActivity.class);
                    MainActivity.this.startActivity(intent);
                }
                else if (itemPosition == 1) // Else, if user clicked on "CreditSale"
                {
                    Intent intent = new Intent(MainActivity.this, CreditSaleActivity.class);
                    MainActivity.this.startActivity(intent);
                }
                else if (itemPosition == 2) // Else, if user clicked on "CreditReturn"
                {
                    Intent intent = new Intent(MainActivity.this, CreditReturnActivity.class);
                    MainActivity.this.startActivity(intent);
                }
                else if (itemPosition == 3) // Else, if user clicked on "GenericVoid"
                {
                    Intent intent = new Intent(MainActivity.this, GenericVoidActivity.class);
                    MainActivity.this.startActivity(intent);
                }
                else if (itemPosition == 4) // Else, if user clicked on "RequestSignature"
                {
                    Intent intent = new Intent(MainActivity.this, RequestSignatureActivity.class);
                    MainActivity.this.startActivity(intent);
                }
            }

        });
    }
}
